@@ -1,7 +1,7 @@
 import dv.fb.Event
 
-class Event(dv.fb.Event.Event):
 
+class Event(dv.fb.Event.Event):
     def __init__(self, fb_event):
         self._fb_event = fb_event
 
@@ -22,12 +22,10 @@ class Event(dv.fb.Event.Event):
         return self._fb_event.Timestamp()
 
     def __str__(self):
-        return '{} ({:3d} {:3d}) | {:8d}'.format('+'
-                                                 if self._fb_event.polarity else '-',
-                                                 self._fb_event.x, self._fb_event.y, self._fb_event.timestamp)
+        return '{} ({:3d} {:3d}) | {:8d}'.format('+' if self._fb_event.Polarity() else '-', self._fb_event.X(),
+                                                 self._fb_event.Y(), self._fb_event.Timestamp())
 
     @classmethod
     def from_fb(cls, obj):
         obj.__class__ = Event
         return obj
-
